# Copyright (C) 2018 NTT DATA
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from django.utils.translation import ugettext_lazy as _

import horizon

from masakaridashboard.default import panel


class MasakariDashboard(horizon.Dashboard):
    slug = "masakaridashboard"
    name = _("Instance-ha")
    panels = ('default', 'segments', 'hosts', 'notifications')
    default_panel = 'default'
    policy_rules = (('instance-ha', 'context_is_admin'),)


horizon.register(MasakariDashboard)
MasakariDashboard.register(panel.Default)
